@@ -3,7 +3,7 @@
 package Test::Rinci;
 
 our $DATE = '2018-11-22'; # DATE
-our $VERSION = '0.151'; # VERSION
+our $VERSION = '0.152'; # VERSION
 
 use 5.010001;
 use strict;
@@ -328,7 +328,7 @@ Test::Rinci - Test Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.151 of Test::Rinci (from Perl distribution Test-Rinci), released on 2018-11-22.
+This document describes version 0.152 of Test::Rinci (from Perl distribution Test-Rinci), released on 2018-11-22.
 
 =head1 SYNOPSIS
 
@@ -445,6 +445,9 @@ feature.
 
 L<test-rinci>, a command-line interface for C<metadata_in_all_modules_ok()>.
 
+L<Test::Rinci::CmdLine> and L<test-rinci-cmdline> to test metadata inside
+L<Perinci::CmdLine> scripts.
+
 L<Rinci>
 
 L<Perinci::Sub::Wrapper>
